/*************************************************************************
 *  
 *  Execution: java -jar SACETableConverter.jar imagename.png outputname.txt
 *
 *  This converter reads each pixel of a PNG file and generated a TXT 
 *  output file containing the following characters: R for red pixels, 
 *  G for green pixels, and Y for yellow pixels. 
 *  This converter was designed for the ICKEPS 2012 competition as part 
 *  of the input data pack of the challenge domain "Planning Solar Array 
 *  Operations on the International Space Station" (SACE).
 *
 *  % java -jar SACETableConverter.jar t1.png output1.txt
 *
 *
 *************************************************************************/

package sacetableconverter;

import java.awt.Color;
import java.io.FileWriter;
import java.io.IOException;

/**
 *
 * @author tiago vaquero
 */
public class SACETableConverter {    
    
    /**
     * Picture pixels to String
     * @param imagename
     * @return 
     */
    public static StringBuilder pic2string(String imagename){
        
        StringBuilder output = new StringBuilder();
        
        Picture pic = new Picture(imagename);
        //System.out.printf("%d-by-%d\n", pic.width(), pic.height());
        //pic.show();

        for (int i = 0; i < pic.height(); i++) {
            String line = "";            
            for (int j = 0; j < pic.width(); j++) {
                Color c = pic.get(j, i);
                int red = c.getRed();
                int green = c.getGreen();
                int blue = c.getBlue();               

                //red
                if (red == 255 && green == 0 && blue == 0){
                    line = line + "R ";                    
                }
                //green
                else if (red == 0 && green == 255 && blue == 0){
                    line = line + "G ";  
                }
                //blue
                else if (red == 0 && green == 0 && blue == 255){
                    line = line + "B ";  
                }
                //yellow
                else if (red == 255 && green == 255 && blue == 0){
                    line = line + "Y ";  
                } 
                //white
                else if (red == 255 && green == 255 && blue == 255){
                    line = line + "W ";  
                }
                else{
                    line = line + "["+red + "," + green + ","+ blue + "]  ";  
                }
            }            
            output.append(line + "\n"); 
        }                          
              
        return output;        
    }
    
    

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        
        if (args.length > 0){
            
            String imagename = args[0];
            String outputname = "";
        
            if (args.length == 2){
                outputname = args[1];
            }
            else{
                outputname = "output.txt";
            }

            System.out.println("Image: " + imagename);
            System.out.println("Output: "+ outputname);
            
            StringBuilder output = pic2string(imagename);
            //System.out.print(output.toString()); 
            
            try {
                FileWriter domainWriter = new FileWriter(outputname);
                domainWriter.write(output.toString());
                domainWriter.close();

            } catch (IOException e1) {
                    e1.printStackTrace();
            }

            System.out.print("Output file generated.\n \n"); 
            
        }
        else{
            System.out.println();
            System.out.println("Please specify the image file and the output file.\n Example:    java -jar SACETableConverter.jar imagename.png outputname.txt \n \n");
        }
        
    }
}
